@@ -289,8 +289,9 @@ editor_set_show_grid (gboolean show)
     return;
 
   editor_show_grid = show;
-  glade_project_foreach_component (current_project, editor_redraw_component,
-				   NULL);
+  if (current_project != NULL)
+    glade_project_foreach_component (current_project, editor_redraw_component,
+				     NULL);
 }
 
 
@@ -410,8 +411,9 @@ on_grid_settings_response (GtkWidget * widget, gint response_id, gpointer data)
   gtk_widget_destroy (dialog);
 
   /* redraw all windows */
-  glade_project_foreach_component (current_project, editor_redraw_component,
-				   NULL);
+  if (current_project != NULL)
+    glade_project_foreach_component (current_project, editor_redraw_component,
+				     NULL);
 }
 
 
@@ -653,8 +655,6 @@ on_placeholder_destroy (GtkWidget * widget,
   /* FIXME: GTK+2 */
   if (!(GTK_OBJECT_FLAGS (current_project) & GTK_IN_DESTRUCTION))
     editor_remove_widget_from_selection (widget);
-  else
-    g_print ("Project IN_DESTRUCTION - not updating selection for placeholder\n");
 }
 
 
@@ -1698,6 +1698,13 @@ editor_select_widget (GtkWidget * widget, GdkEventButton * event,
 
       drag_widget_x1 = widget->allocation.x;
       drag_widget_y1 = widget->allocation.y;
+
+      if (GTK_IS_FIXED (widget->parent))
+	{
+	  drag_widget_x1 -= widget->parent->allocation.x;
+	  drag_widget_y1 -= widget->parent->allocation.y;
+	}
+
       drag_widget_x2 = drag_widget_x1 + widget->allocation.width;
       drag_widget_y2 = drag_widget_y1 + widget->allocation.height;
 
@@ -1979,7 +1986,20 @@ editor_do_drag_action (GtkWidget * signal_widget, GdkEventMotion * event)
   old_width = widget->allocation.width;
   old_height = widget->allocation.height;
 
+  /* GtkFixed doesn't normally have a window now, so we need to subtract its
+     position so our coordinates are relative to it. */
+  if (GTK_IS_FIXED (widget->parent))
+    {
+      old_x -= widget->parent->allocation.x;
+      old_y -= widget->parent->allocation.y;
+    }
+
   gdk_window_get_pointer (widget->parent->window, &mouse_x, &mouse_y, NULL);
+  if (GTK_IS_FIXED (widget->parent))
+    {
+      mouse_x -= widget->parent->allocation.x;
+      mouse_y -= widget->parent->allocation.y;
+    }
   if (GTK_IS_LAYOUT (widget->parent))
     {
       mouse_x += GTK_LAYOUT (widget->parent)->hadjustment->value;
@@ -2277,8 +2297,10 @@ on_size_allocate (GtkWidget * widget,
       if (widget->parent && GTK_IS_FIXED (widget->parent))
 	{
 	  property_set_auto_apply (FALSE);
-	  property_set_int (GladeFixedChildX, allocation->x);
-	  property_set_int (GladeFixedChildY, allocation->y);
+	  property_set_int (GladeFixedChildX,
+			    allocation->x - widget->parent->allocation.x);
+	  property_set_int (GladeFixedChildY,
+			    allocation->y - widget->parent->allocation.y);
 	  property_set_auto_apply (TRUE);
 	}
       else if (widget->parent && GTK_IS_LAYOUT (widget->parent))
@@ -2570,9 +2592,13 @@ draw_grid (GtkWidget * widget)
     }
   else
     {
+      /* The GtkFixed container doesn't have a window in GTK+ 2.0 (by default),
+	 so we have to use the allocation. */
       window = widget->window;
-      origin_x = 0;
-      origin_y = 0;
+      origin_x = widget->allocation.x;
+      origin_y = widget->allocation.y;
+      max_x += origin_x;
+      max_y += origin_y;
     }
 
   /* Note: should we take the border_width into account? - i.e. start the
@@ -3276,7 +3302,6 @@ editor_delete_widget (GtkWidget * widget)
      widget in the same position. */
   placeholder = editor_new_placeholder ();
   gtk_widget_ref (placeholder);
-  g_print ("Replacing widget with placeholder\n");
   if (gb_widget_replace_child (widget->parent, widget, placeholder))
     {
       if (placeholder->parent)
