@@ -133,7 +133,7 @@ gb_label_create_standard_properties (GtkWidget * widget,
 
   property_add_text (label_p, _("Label:"), _("The text to display"), 2);
   property_add_bool (use_underline_p, _("Use Underline:"),
-		     _("If the text include an underlined accelerator character"));
+		     _("If the text includes an underlined accelerator character"));
   property_add_bool (use_markup_p, _("Use Markup:"),
 		     _("If the text includes pango markup"));
   property_add_choice (justify_p, _("Justify:"),
@@ -582,7 +582,7 @@ gb_label_write_standard_source (GtkWidget * widget,
   gint i;
 
   if (gtk_object_get_data (GTK_OBJECT (widget), use_markup_p))
-    source_add (data, "  gtk_label_set_use_markup (%s, TRUE);\n",
+    source_add (data, "  gtk_label_set_use_markup (GTK_LABEL (%s), TRUE);\n",
 		data->wname);
 
   /* If there is an underlined accelerator, set up the accel signal.
