@@ -29,54 +29,43 @@
 
 GbWidget *gb_gnome_db_browser_init ();
 GbWidget *gb_gnome_db_combo_init ();
+GbWidget *gb_gnome_db_dsnconfig_init ();
 GbWidget *gb_gnome_db_error_init ();
 GbWidget *gb_gnome_db_errordlg_init ();
 GbWidget *gb_gnome_db_grid_init ();
 GbWidget *gb_gnome_db_list_init ();
 GbWidget *gb_gnome_db_login_init ();
 GbWidget *gb_gnome_db_logindlg_init ();
-GbWidget *gb_gnome_db_report_init ();
-GbWidget *gb_gnome_db_iconlist_init ();
-GbWidget *gb_gnome_db_dsnconfig_init ();
-GbWidget *gb_gnome_db_dataset_init ();
-
-GbWidget * gb_gnome_db_list_init (); 
-GbWidget *gb_gnome_db_report_init ();
-GbWidget *gb_gnome_db_iconlist_init ();
-GbWidget *gb_gnome_db_designer_init ();
-/*GbWidget *gb_gnome_db_entry_init ();*/
-GbWidget *gb_gnome_db_export_init ();
-/*GbWidget *gb_gnome_db_label_init ();*/
-GbWidget *gb_gnome_db_log_viewer_init ();
-GbWidget *gb_gnome_db_report_init ();
 GbWidget *gb_gnome_db_table_editor_init ();
 
 static GladeWidgetInitData gnome_db[] = {
+        { "GnomeDbLoginDialog", gb_gnome_db_logindlg_init },
 	{ "GnomeDbLogin",       gb_gnome_db_login_init },
-        { "GnomeDbLoginDlg",    gb_gnome_db_logindlg_init },
+        { "GnomeDbErrorDialog", gb_gnome_db_errordlg_init }, 
+        { "GnomeDbError",       gb_gnome_db_error_init },
+
         { "GnomeDbDsnConfig",   gb_gnome_db_dsnconfig_init },
         { "GnomeDbBrowser",     gb_gnome_db_browser_init },
         { "GnomeDbGrid",        gb_gnome_db_grid_init },
-        { "GnomeDbDataset",     gb_gnome_db_dataset_init },
+        /*{ "GnomeDbDataset",     gb_gnome_db_dataset_init },*/
         { "GnomeDbCombo",       gb_gnome_db_combo_init },
         { "GnomeDbList",        gb_gnome_db_list_init },
-        { "GnomeDbReport",      gb_gnome_db_report_init },
-        { "GnomeDbIconList",    gb_gnome_db_iconlist_init },
-        { "GnomeDbError",       gb_gnome_db_error_init },
-        { "GnomeDbErrorDlg",    gb_gnome_db_errordlg_init }, 
-	{ "GnomeDbDesigner",	gb_gnome_db_designer_init },
+        /*{ "GnomeDbReport",      gb_gnome_db_report_init },*/
+        /*{ "GnomeDbIconList",    gb_gnome_db_iconlist_init },*/
+	/*{ "GnomeDbDesigner",	gb_gnome_db_designer_init },*/
 	/*{ "GnomeDbEntry",	gb_gnome_db_entry_init },*/
-	{ "GnomeDbExport",	gb_gnome_db_export_init },
+	/*{ "GnomeDbExport",	gb_gnome_db_export_init },*/
 	/*{ "GnomeDbLabel",	gb_gnome_db_label_init },*/
-	{ "GnomeDbLogviewer",	gb_gnome_db_log_viewer_init },
-	{ "GnomeDbTableeditor",	gb_gnome_db_table_editor_init },
+	/*{ "GnomeDbLogviewer",	gb_gnome_db_log_viewer_init },*/
+	/*{ "GnomeDbReport",	gb_gnome_db_report_init },*/
+	{ "GnomeDbTableEditor",	gb_gnome_db_table_editor_init },
 	{ NULL, NULL }  
 };
 
 
 static GladePaletteSectionData sections[] =
 {
-  { "Gnome DB", gnome_db },
+  { "Gnome _DB", gnome_db },
   { NULL, NULL }
 };
 
