@@ -144,28 +144,39 @@ static void glade_project_window_update_title (GladeProjectWindow *project_windo
 
 
 
-#if 0
+#ifdef USE_GNOME
 static void
-glade_project_window_show_help1 (GtkWidget *widget,
-				 gpointer data)
+glade_project_window_show_help_doc (const gchar *docname,
+				    GtkWidget *transient_widget)
 {
   GError *error = NULL;
 
-  g_print ("In glade_project_window_show_help1\n");
-
-  g_print ("  Showing glade-user-guide\n");
-
-  /*gnome_help_display ("glade-user-guide", NULL, &error);*/
-  /*gnome_help_display_with_doc_id (NULL, "", "glade-user-guide", NULL, &error);*/
-
-  /*gnome_help_display_uri ("ghelp://glade-user-guide", &error);*/
-  gnome_url_show ("ghelp://glade-user-guide", &error);
-
+  gnome_help_display (docname, NULL, &error);
   if (error) {
-    g_print ("  Error: %s\n", error->message);
+    char *message;
+    message = g_strdup_printf (_("Couldn't show help file: %s.\n\nError: %s"),
+			       docname, error->message);
+    glade_util_show_message_box	(message, transient_widget);
+    g_free (message);
     g_error_free (error);
   }
 }
+
+
+static void
+glade_project_window_show_turbo_start (GtkWidget *menuitem,
+				       gpointer data)
+{
+  glade_project_window_show_help_doc ("glade-turbo-start", menuitem);
+}
+
+
+static void
+glade_project_window_show_glade_faq (GtkWidget *menuitem,
+				     gpointer data)
+{
+  glade_project_window_show_help_doc ("glade-faq", menuitem);
+}
 #endif
 
 
@@ -297,21 +308,24 @@ static GnomeUIInfo SettingsMenu[] =
 
 static GnomeUIInfo HelpMenu[] =
 {
-#if 0
   GNOMEUIINFO_HELP ("glade-user-guide"),
-
   {
-    GNOME_APP_UI_ITEM, N_("Help 1"),
-    N_("Show some help document"),
-    glade_project_window_show_help1, NULL, NULL,
+    GNOME_APP_UI_ITEM, N_("_Turbo Start"),
+    N_("View the turbo start guide"),
+    glade_project_window_show_turbo_start, NULL, NULL,
+    GNOME_APP_PIXMAP_NONE, NULL,
+    0, 0, NULL
+  },
+  {
+    GNOME_APP_UI_ITEM, N_("_FAQ"),
+    N_("View the Glade FAQ"),
+    glade_project_window_show_glade_faq, NULL, NULL,
     GNOME_APP_PIXMAP_NONE, NULL,
     0, 0, NULL
   },
 
   GNOMEUIINFO_SEPARATOR,
 
-#endif
-
   GNOMEUIINFO_MENU_ABOUT_ITEM (glade_project_window_about, NULL),
   GNOMEUIINFO_END
 };
@@ -391,7 +405,7 @@ glade_project_window_new (void)
   gtk_object_set_data (GTK_OBJECT (project_window->window),
 		       GladeProjectWindowKey, project_window);
 
-  /*gtk_widget_set_uposition (project_window->window, 0, 0);*/
+  gtk_window_move (GTK_WINDOW (project_window->window), 0, 0);
 
   gtk_signal_connect (GTK_OBJECT (project_window->window), "destroy",
 		      GTK_SIGNAL_FUNC (glade_project_window_destroy), NULL);
@@ -535,7 +549,7 @@ glade_project_window_new (void)
   gtk_object_set_data (GTK_OBJECT (project_window->window),
 		       GladeProjectWindowKey, project_window);
 
-  /*gtk_widget_set_uposition (project_window->window, 0, 0);*/
+  gtk_window_move (GTK_WINDOW (project_window->window), 0, 0);
 
   gtk_signal_connect (GTK_OBJECT (project_window->window), "destroy",
 		      GTK_SIGNAL_FUNC (glade_project_window_destroy), NULL);
