@@ -440,25 +440,21 @@ session_save_yourself_cb (GnomeClient *client, gint phase,
 
   if (!glade_palette || !GTK_WIDGET_VISIBLE (glade_palette))
     {
-      g_print ("Palette hidden\n");
       argv[arg++] = "--hide-palette";
     }
 
   if (!win_property || !GTK_WIDGET_VISIBLE (win_property))
     {
-      g_print ("Property editor hidden\n");
       argv[arg++] = "--hide-property-editor";
     }
 
   if (win_tree && GTK_WIDGET_VISIBLE (win_tree))
     {
-      g_print ("Widget tree shown\n");
       argv[arg++] = "--show-widget-tree";
     }
 
   if (glade_clipboard && GTK_WIDGET_VISIBLE (glade_clipboard))
     {
-      g_print ("Clipboard shown\n");
       argv[arg++] = "--show-clipboard";
     }
 
