@@ -661,11 +661,12 @@ source_write_interface_c_preamble (GbWidgetWriteSourceData * data, FILE *fp)
 
   if (glade_project_get_gnome_support (data->project))
     {
+      fprintf (fp, "#include <bonobo.h>\n");
       fprintf (fp, "#include <gnome.h>\n");
 
       if (glade_project_get_gnome_db_support (data->project))
 	{
-	  fprintf (fp, "#include <gda-ui.h>\n");
+	  fprintf (fp, "#include <libgnomedb/libgnomedb.h>\n");
 	}
     }
   else
