@@ -2117,15 +2117,27 @@ glade_util_string_from_flags (GType type, guint flags)
 
 
 /* Returns TRUE if the widget should have a border width property.
-   Containers normally do, but Bonobo controls don't. */
+   Containers normally do, but Bonobo controls don't.
+   Also, GtkDialog widgets and their action area hbuttonboxes don't, as they
+   use style properties. */
 gboolean
 glade_util_uses_border_width (GtkWidget *widget)
 {
+  char *child_name = gb_widget_get_child_name (widget);
+
 #ifdef USE_GNOME
   if (BONOBO_IS_WIDGET (widget))
     return FALSE;
 #endif
 
+  /* The GtkDialog vbox has its border width set from a style property, so
+     we shouldn't show the property in Glade. */
+  if (GTK_IS_VBOX (widget) && widget->parent && GTK_IS_DIALOG (widget->parent))
+    return FALSE;
+
+  if (child_name && !strcmp (child_name, GladeChildDialogActionArea))
+    return FALSE;
+
   if (GTK_IS_CONTAINER (widget))
     return TRUE;
 
